#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 character-ps
version:              0.1
visibility:           public
id:                   character-ps-0.1-H07uOjD6SD1EfE7l9KfeMv
key:                  character-ps-0.1-H07uOjD6SD1EfE7l9KfeMv
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/character-ps
synopsis:             Pattern synonyms for ASCII characters for Word8, Word16 etc
description:
    Pattern synonyms for ASCII characters, e.g.

    @
    pattern SPACE :: Word8
    pattern SPACE = 0x20
    @

category:             Data
abi:                  a054611e2de4321f4998767f80d73241
exposed:              True
exposed-modules:
    Data.Char.Patterns Data.Word16.Patterns Data.Word8.Patterns

import-dirs:          /usr/lib/ghc-9.6.6/site-local/character-ps-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/character-ps-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/character-ps-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-character-ps
hs-libraries:         HScharacter-ps-0.1-H07uOjD6SD1EfE7l9KfeMv
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-character-ps/html/character-ps.haddock

haddock-html:         /usr/share/doc/haskell-character-ps/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

